import { MarkerOverlayPoint } from '../overlay/MarkerOverlayPoint';
import { OverlayPoint } from '../overlay/OverlayPoint';
import { type UndefIterator } from '../../../util/iterator';
import { Inline } from './Inline';
import type { Path } from '../../../json-pointer';
import type { Printable } from 'tree-dump';
import type { Peritext } from '../Peritext';
import type { Stateful } from '../types';
import type { OverlayTuple } from '../overlay/types';
export interface IBlock {
    readonly path: Path;
    readonly parent: IBlock | null;
}
type T = string;
export declare class Block<Attr = unknown> implements IBlock, Printable, Stateful {
    readonly txt: Peritext;
    readonly path: Path;
    readonly marker: MarkerOverlayPoint | undefined;
    parent: Block | null;
    children: Block[];
    constructor(txt: Peritext, path: Path, marker: MarkerOverlayPoint | undefined);
    /**
     * @returns Stable unique identifier within a list of blocks. Used for React
     * or other rendering library keys.
     */
    key(): number | string;
    tag(): number | string;
    attr(): Attr | undefined;
    /**
     * Iterate through all overlay points of this block, until the next marker
     * (regardless if that marker is a child or not).
     */
    points0(withMarker?: boolean): UndefIterator<OverlayPoint<T>>;
    points(withMarker?: boolean): IterableIterator<OverlayPoint<T>>;
    tuples0(): UndefIterator<OverlayTuple<T>>;
    tuples(): IterableIterator<OverlayTuple<T>>;
    texts0(): UndefIterator<Inline>;
    texts(): IterableIterator<Inline>;
    text(): string;
    hash: number;
    refresh(): number;
    protected toStringHeader(): string;
    toString(tab?: string): string;
}
export {};
