"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Blocks = void 0;
const Block_1 = require("./Block");
const commonLength_1 = require("../util/commonLength");
const printTree_1 = require("tree-dump/lib/printTree");
const LeafBlock_1 = require("./LeafBlock");
class Blocks {
    constructor(txt) {
        this.txt = txt;
        // ----------------------------------------------------------------- Stateful
        this.hash = 0;
        this.root = new Block_1.Block(txt, [], undefined);
    }
    // ---------------------------------------------------------------- Printable
    toString(tab = '') {
        return this.constructor.name + (0, printTree_1.printTree)(tab, [(tab) => this.root.toString(tab)]);
    }
    refresh() {
        this.refreshBlocks();
        return (this.hash = this.root.refresh());
    }
    insertBlock(parent, path, marker) {
        const txt = this.txt;
        const common = (0, commonLength_1.commonLength)(path, parent.path);
        while (parent.path.length > common && parent.parent)
            parent = parent.parent;
        while (parent.path.length + 1 < path.length) {
            const block = new Block_1.Block(txt, path.slice(0, parent.path.length + 1), undefined);
            block.parent = parent;
            parent.children.push(block);
            parent = block;
        }
        const block = new LeafBlock_1.LeafBlock(txt, path, marker);
        block.parent = parent;
        parent.children.push(block);
        return block;
    }
    refreshBlocks() {
        this.root.children = [];
        let parent = this.root;
        let markerPoint;
        const txt = this.txt;
        const overlay = txt.overlay;
        this.insertBlock(parent, [0], undefined);
        const iterator = overlay.markers0(undefined);
        while ((markerPoint = iterator())) {
            const type = markerPoint.type();
            const path = type instanceof Array ? type : [type];
            const block = this.insertBlock(parent, path, markerPoint);
            if (block.parent)
                parent = block.parent;
        }
    }
}
exports.Blocks = Blocks;
