import { OverlayPoint } from '../overlay/OverlayPoint';
import { Range } from '../rga/Range';
import { ChunkSlice } from '../util/ChunkSlice';
import type { AbstractRga } from '../../../json-crdt/nodes/rga';
import type { Printable } from 'tree-dump/lib/types';
import type { Peritext } from '../Peritext';
export type InlineAttributes = Record<string | number, unknown>;
/**
 * The `Inline` class represents a range of inline text within a block, which
 * has the same annotations and formatting for all of its text contents, i.e.
 * its text contents can be rendered as a single (`<span>`) element. However,
 * the text contents might still be composed of multiple {@link ChunkSlice}s,
 * which are the smallest units of text and need to be concatenated to get the
 * full text content of the inline.
 */
export declare class Inline extends Range implements Printable {
    start: OverlayPoint;
    end: OverlayPoint;
    /**
     * @todo PERF: for performance reasons, we should consider not passing in
     * this array. Maybe pass in just the initial chunk and the offset. However,
     * maybe even the just is not necessary, as the `.start` point should have
     * its chunk cached, or will have it cached after the first access.
     */
    readonly texts: ChunkSlice[];
    static create(txt: Peritext, start: OverlayPoint, end: OverlayPoint): Inline;
    constructor(rga: AbstractRga<string>, start: OverlayPoint, end: OverlayPoint, 
    /**
     * @todo PERF: for performance reasons, we should consider not passing in
     * this array. Maybe pass in just the initial chunk and the offset. However,
     * maybe even the just is not necessary, as the `.start` point should have
     * its chunk cached, or will have it cached after the first access.
     */
    texts: ChunkSlice[]);
    /**
     * @returns A stable unique identifier of this *inline* within a list of other
     *     inlines of the parent block. Can be used for UI libraries to track the
     *     identity of the inline across renders.
     */
    key(): number;
    /**
     * @returns The position of the inline withing the text.
     */
    pos(): number;
    /**
     * @returns Returns the attributes of the inline, which are the slice
     *     annotations and formatting applied to the inline.
     */
    attr(): InlineAttributes;
    toString(tab?: string): string;
}
