import { Point } from '../rga/Point';
import { CursorAnchor } from '../slice/constants';
import { PersistedSlice } from '../slice/PersistedSlice';
export declare class Cursor<T = string> extends PersistedSlice<T> {
    get anchorSide(): CursorAnchor;
    set anchorSide(value: CursorAnchor);
    anchor(): Point<T>;
    focus(): Point<T>;
    set(start: Point<T>, end?: Point<T>, anchorSide?: CursorAnchor): void;
    /**
     * Move one of the edges of the cursor to a new point.
     *
     * @param point Point to set the edge to.
     * @param endpoint 0 for "focus", 1 for "anchor."
     */
    setEndpoint(point: Point<T>, endpoint?: 0 | 1): void;
    move(move: number): void;
    /**
     * Ensures there is no range selection. If user has selected a range,
     * the contents is removed and the cursor is set at the start of the range as cursor.
     *
     * @todo If block boundaries are withing the range, remove the blocks.
     * @todo Stress test this method.
     *
     * @returns Returns the cursor position after the operation.
     */
    collapse(): void;
    /**
     * Insert inline text at current cursor position. If cursor selects a range,
     * the range is removed and the text is inserted at the start of the range.
     */
    insert(text: string): void;
    delBwd(): void;
    toStringName(): string;
}
