import { Cursor } from './Cursor';
import { PersistedSlice } from '../slice/PersistedSlice';
import { EditorSlices } from './EditorSlices';
import type { ITimestampStruct } from '../../../json-crdt-patch/clock';
import type { Peritext } from '../Peritext';
import type { SliceType } from '../slice/types';
import type { MarkerSlice } from '../slice/MarkerSlice';
export declare class Editor<T = string> {
    readonly txt: Peritext<T>;
    readonly saved: EditorSlices<T>;
    readonly extra: EditorSlices<T>;
    readonly local: EditorSlices<T>;
    constructor(txt: Peritext<T>);
    firstCursor(): Cursor<T> | undefined;
    /**
     * Returns the first cursor in the text. If there is no cursor, creates one
     * and inserts it at the start of the text. To work with multiple cursors, use
     * `.cursors()` method.
     *
     * Cursor is the the current user selection. It can be a caret or a range. If
     * range is collapsed to a single point, it is a *caret*.
     */
    get cursor(): Cursor<T>;
    cursors(callback: (cursor: Cursor<T>) => void): void;
    delCursors(): void;
    /**
     * Insert inline text at current cursor position. If cursor selects a range,
     * the range is removed and the text is inserted at the start of the range.
     */
    insert(text: string): void;
    /**
     * Deletes the previous character at current cursor position. If cursor
     * selects a range, deletes the whole range.
     */
    delBwd(): void;
    /** @todo Add main impl details of this to `Cursor`, but here ensure there is only one cursor. */
    selectAll(): boolean;
    /** @deprecated use `.saved.insStack` */
    insStackSlice(type: SliceType, data?: unknown | ITimestampStruct): PersistedSlice<T>;
    /** @deprecated use `.saved.insOverwrite` */
    insOverwriteSlice(type: SliceType, data?: unknown | ITimestampStruct): PersistedSlice<T>;
    /** @deprecated use `.saved.insErase` */
    insEraseSlice(type: SliceType, data?: unknown | ITimestampStruct): PersistedSlice<T>;
    /** @deprecated use `.saved.insMarker` */
    insMarker(type: SliceType, data?: unknown): MarkerSlice<T>;
}
