/**
 * Specifies whether the start or the end of the cursor is the "anchor", e.g.
 * the end which does not move when user changes selection. The other
 * end is free to move, the moving end of the cursor is "focus". By default
 * "anchor" is usually the start of the cursor.
 */
export declare const enum CursorAnchor {
    Start = 0,
    End = 1
}
export declare const enum Tags {
    Cursor = 0
}
export declare const enum SliceHeaderMask {
    X1Anchor = 1,
    X2Anchor = 2,
    Behavior = 28
}
export declare const enum SliceHeaderShift {
    X1Anchor = 0,
    X2Anchor = 1,
    Behavior = 2
}
export declare const enum SliceBehavior {
    /**
     * A Split slice, which is used to mark a block split position in the document.
     * For example, paragraph, heading, blockquote, etc.
     */
    Marker = 0,
    /**
     * Appends attributes to a stack of attributes for a specific slice type. This
     * is useful when the same slice type can have multiple attributes, like
     * inline comments, highlights, etc.
     */
    Stack = 1,
    /**
     * Overwrites the stack of attributes for a specific slice type. Could be used
     * for simple inline formatting, like bold, italic, etc.
     */
    Overwrite = 2,
    /**
     * Removes all attributes for a specific slice type. For example, could be
     * used to re-verse inline formatting, like bold, italic, etc.
     */
    Erase = 3,
    /**
     * Used to mark the user's cursor position in the document.
     *
     * @todo Consider removing this.
     */
    Cursor = 4
}
export declare enum SliceBehaviorName {
    Marker = 0,
    Stack = 1,
    Overwrite = 2,
    Erase = 3,
    Cursor = 4
}
/**
 * Specifies `vec` offsets in the {@link SliceView}.
 */
export declare const enum SliceTupleIndex {
    Header = 0,
    X1 = 1,
    X2 = 2,
    Type = 3,
    Data = 4
}
