"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validate = void 0;
const validate = (op) => {
    if (!(op instanceof Array))
        return 1 /* VALIDATE_RESULT.INVALID_OP */;
    if (op.length === 0)
        return 1 /* VALIDATE_RESULT.INVALID_OP */;
    let last;
    for (let i = 0; i < op.length; i++) {
        const component = op[i];
        switch (typeof component) {
            case 'number': {
                if (!component)
                    return 2 /* VALIDATE_RESULT.INVALID_COMPONENT */;
                if (component !== Math.round(component))
                    return 2 /* VALIDATE_RESULT.INVALID_COMPONENT */;
                if (component > 0) {
                    const lastComponentIsRetain = typeof last === 'number' && last > 0;
                    if (lastComponentIsRetain)
                        return 3 /* VALIDATE_RESULT.ADJACENT_SAME_TYPE */;
                }
                else {
                    const lastComponentIsDelete = typeof last === 'number' && last < 0;
                    if (lastComponentIsDelete)
                        return 3 /* VALIDATE_RESULT.ADJACENT_SAME_TYPE */;
                }
                break;
            }
            case 'string': {
                if (!component.length)
                    return 2 /* VALIDATE_RESULT.INVALID_COMPONENT */;
                const lastComponentIsInsert = typeof last === 'string';
                if (lastComponentIsInsert)
                    return 3 /* VALIDATE_RESULT.ADJACENT_SAME_TYPE */;
                break;
            }
            case 'object': {
                if (!(component instanceof Array))
                    return 2 /* VALIDATE_RESULT.INVALID_COMPONENT */;
                if (component.length !== 1)
                    return 2 /* VALIDATE_RESULT.INVALID_COMPONENT */;
                const lastComponentIsRetainedDelete = last instanceof Array;
                if (lastComponentIsRetainedDelete)
                    return 3 /* VALIDATE_RESULT.ADJACENT_SAME_TYPE */;
                break;
            }
            default:
                return 2 /* VALIDATE_RESULT.INVALID_COMPONENT */;
        }
        last = component;
    }
    const isLastRetain = typeof last === 'number' && last > 0;
    if (isLastRetain)
        return 4 /* VALIDATE_RESULT.NO_TRAILING_RETAIN */;
    return 0 /* VALIDATE_RESULT.SUCCESS */;
};
exports.validate = validate;
